FragmentRequest<TData, TVars> class abstract interface

Properties

document → DocumentNode
no setter
fragmentName → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
idFields → Map<String, dynamic>
A map of id fields, based on TypePolicy.keyFields for the given type, and their respective values. By default, id or _id are used.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vars → TVars
no setter

Methods

dataToJson(TData data) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseData(Map<String, dynamic> json) → TData?
This is a simple wrapper on the static fromJson method on the generated class.
toString() → String
A string representation of this object.
inherited
varsToJson() → Map<String, dynamic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited