BoxCollection class abstract

Constructors

BoxCollection()

Properties

boxNames → Set<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
deleteFromDisk() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBox<V>(String name, {bool preload = false, CollectionBox<V> boxCreator(String, BoxCollection)?}) → Future<CollectionBox<V>>
toString() → String
A string representation of this object.
inherited
transaction(Future<void> action(), {List<String>? boxNames, bool readOnly = false}) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

open(String name, Set<String> boxNames, {String? path, HiveCipher? key}) → Future<BoxCollection>