CacheTypedLink class

A terminating link that fetches the operation from the Cache, mapping the result to an OperationResponse.

Inheritance

Constructors

CacheTypedLink([Cache? cache])

Properties

cache ↔ Cache
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

concat(TypedLink next) → TypedLink
Adds next after this typedLink
inherited
dispose() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<TData, TVars>(OperationRequest<TData, TVars> operationRequest, [NextTypedLink<TData, TVars>? forward]) → Stream<OperationResponse<TData, TVars>>
A function called when a request reaches this TypedLink
override
route(TypedLinkRouter route) → TypedLink
Route requests after this typedLink
inherited
split(bool test<TData, TVars>(OperationRequest<TData, TVars> request), TypedLink left, [TypedLink right = const PassthroughTypedLink()]) → TypedLink
Split requests after this typedLink
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited