CollectionBox<V> class abstract

represents a Box being part of a BoxCollection

Constructors

CollectionBox()

Properties

boxCollection → BoxCollection
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
delete(String key) → Future<void>
deleteAll(List<String> keys) → Future<void>
flush() → Future<void>
get(String key) → Future<V?>
getAll(List<String> keys) → Future<List<V?>>
getAllKeys() → Future<List<String>>
getAllValues() → Future<Map<String, V>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, V val, [Object? transaction]) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited