HiveType class

Annotate classes with HiveType to generate a TypeAdapter.

Constructors

HiveType({required int typeId, String? adapterName})
This parameter can be used to keep track of old fieldIds which must not be reused. The generator will throw an error if a legacy fieldId is used again. If adapterName is not set, it'll be "YourClass" + "Adapter".
const

Properties

adapterName → String?
The name of the generated adapter.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeId → int
The typeId of the annotated class.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited