RequestControllerTypedLink class

Allows multiple requests to be made by adding requests to the requestController.

To refetch an operation, simply add a new request of the same type and with the same OperationRequest.requestId.

To implement pagination, include an OperationRequest.updateResult callback.

If OperationRequest.executeOnListen == true, the operation will be immediately executed when the stream returned by request is first listened to.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestController ↔ StreamController<OperationRequest>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

concat(TypedLink next) → TypedLink
Adds next after this typedLink
inherited
dispose() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<TData, TVars>(OperationRequest<TData, TVars> request, [NextTypedLink<TData, TVars>? forward]) → Stream<OperationResponse<TData, TVars>>
A function called when a request reaches this TypedLink
override
route(TypedLinkRouter route) → TypedLink
Route requests after this typedLink
inherited
split(bool test<TData, TVars>(OperationRequest<TData, TVars> request), TypedLink left, [TypedLink right = const PassthroughTypedLink()]) → TypedLink
Split requests after this typedLink
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited