TypeAdapter<T> class abstract

Type adapters can be implemented to support non primitive values.

Annotations
  • @immutable

Constructors

TypeAdapter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeId → int
Called for type registration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(BinaryReader reader) → T
Is called when a value has to be decoded.
toString() → String
A string representation of this object.
inherited
write(BinaryWriter writer, T obj) → void
Is called when a value has to be encoded.

Operators

operator ==(Object other) → bool
The equality operator.
inherited