TypeRegistry class abstract

TypeRegistries contain the TypeAdapters associated with a typeId.

TypeIds have to be unique and must not change.

Constructors

TypeRegistry()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ignoreTypeId<T>(int typeId) → void
Ignore type
isAdapterRegistered(int typeId) → bool
Returns true if a TypeAdapter is registered
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAdapter<T>(TypeAdapter<T> adapter, {bool internal = false, bool override = false}) → void
Register a TypeAdapter to announce it to Hive.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited